cordex.tables.data\_request package
===================================

Module contents
---------------

.. automodule:: cordex.tables.data_request
   :members:
   :undoc-members:
   :show-inheritance:
